function love.run()
	-- Some global stuff that probably won't need to be here for long
	global = {}
	global.scale = 1				-- Scale of the screen
	global.tx = 0					-- X translation of the screen
	global.ty = 0					-- Y translation of the screen

	fpsCount = 0			-- FPS count of the current second
	fpsTime = 0				-- Keeps track of the elapsed time
	
	if love.load then love.load(arg) end

	local dt = 0

	-- Main loop time.
	while true do
		if love.timer then
			love.timer.step()
			dt = love.timer.getDelta()
		end
		if love.update then love.update(dt) end -- will pass 0 if love.timer is disabled
		if love.graphics then
			love.graphics.clear()
			if love.draw then love.draw() end
		end

		-- Process events.
		if love.event then
			for e,a,b,c in love.event.poll() do
				if e == "q" then
					if not love.quit or not love.quit() then
						if love.audio then
							love.audio.stop()
						end
						return
					end
				end
				love.handlers[e](a,b,c)
			end
		end

		if love.timer then love.timer.sleep(1) end
		if love.graphics then love.graphics.present() end
    end
end

function love.load()
	MapGen = require("MapGen")
	map = MapGen.Generate(100,100,10,0.05)
end

-- Scroll in and out
function love.mousepressed( x, y, mb )
	if mb == "wu" then
		global.scale = global.scale + 0.2
	end

	if mb == "wd" then
		global.scale = global.scale - 0.2
	end
end

function love.update(dt)
	-- Move the camera
	if love.keyboard.isDown("up") then global.ty = global.ty + 250*dt end
	if love.keyboard.isDown("down") then global.ty = global.ty - 250*dt end
	if love.keyboard.isDown("left") then global.tx = global.tx + 250*dt end
	if love.keyboard.isDown("right") then global.tx = global.tx - 250*dt end
	
	-- Count the frames per second
	fpsCount = fpsCount+1
	fpsTime = fpsTime + dt
	if fpsTime >= 1 then
		fps = fpsCount
		fpsTime = 0
		fpsCount = 0
	end
end

function love.keypressed(k)
	-- quit
    if k == 'escape' then
        love.event.push('q')
    end
end

function love.draw()
	local ftx, fty = math.floor(global.tx), math.floor(global.ty)
	love.graphics.push()
	love.graphics.scale(global.scale)
	love.graphics.translate(ftx, fty)
	MapGen.Draw(map)
	
	love.graphics.pop()
end